@@ -77,13 +77,6 @@ the site on mobile browsers, so always upload an image that will look good on \
 normal web browsers. In general an image with an aspect ratio of 4:3 will \
 yield best results."""
 
-        self.fields['crop_from'].help_text = """If you upload an image in an \
-aspect ratio that may require it to be cropped then you can adjust from where \
-the cropping takes place. This is useful to prevent peoples' heads from being \
-chopped off."""
-
-        self.fields['effect'].help_text = """Apply an effect to the image."""
-
         # Add relations fields
         content_type = ContentType.objects.get_for_model(self._meta.model)
         relations = Relation.objects.filter(source_content_type=content_type)
@@ -138,7 +131,7 @@ class ModelBaseAdmin(admin.ModelAdmin):
         (
             'Image',
             {
-                'fields': ('image', 'crop_from', 'image_attribution'),
+                'fields': ('image', 'image_attribution'),
                 'classes': ()
             }
         ),
@@ -174,13 +167,6 @@ class ModelBaseAdmin(admin.ModelAdmin):
                 'classes': ('collapse',)
             }
         ),
-        (
-            'Advanced',
-            {
-                'fields': ('effect',),
-                'classes': ('collapse',)
-            }
-        ),
     )
 
     def __init__(self, model, admin_site):
